# SEC09-BP02: Enforce encryption in transit

## Description

HTTPS everywhere.

## Implementation Guidance

- Enforce HTTPS on all endpoints
- Internal traffic encryption
- VPC endpoint private traffic
- Database connection encryption
- API gateway TLS

## Risk Level

High - Unencrypted traffic can be intercepted.
